@@ -28,7 +28,7 @@ if hasattr(settings, 'USE_APP_THEME_UI_ADMIN'):
         def save_model(self, request, obj, form, change):
             list_settings = ThemeUI.objects.all()
             for setting in list_settings:
-                setting.apply = False
+                setting.applied = False
                 setting.save()
 
             obj.save()
